function [usrec,nE] = Box41ppcomplex(datcoef,winchi,tt,xi,xcte1,xcte2,S2,AMPS,pswf,N,Nip,OS,Norm,eps)
%% function [usrec,nE] = Box41ppcomplex(datcoef,winchi,tt,xi,xcte1,xcte2,S2,AMPS,pswf,N,Nip,OS,Norm,eps)
% Prolate approximate propagation of single box
% ---input: 
% datcoef - wave packet coefficients of box
% winchi - window function of box
% xi - frequency grid of box
% xcte1, xcte2 - coordinate transform: spatial evaluation points of adjoint USFFT
% S2 - 2nd partial derivative ov generating function corresponding to data grid
% AMPS - amplitudes corresponding to (xcte1, xcte2)
% pswf - data structure with prolates for complex exponential separated representation
% N,Nip,OS,eps - image size, interpolation points, oversampling, precision
% ---output: 
% usrec - propagated data
% nE - number of expansion terms used

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% --- define space and frequencies
m=Nip; n=Nip;
mm=2^(ceil(log2(m))+OS(2)); nn=2^(ceil(log2(n))+OS(1));
NZ1=mm; DZ1=(NZ1-m)/2; NZ2=nn; DZ2=(NZ2-n)/2;

% regularly spaced frequencies for CT USFFT
xx1=([0:mm-1])-(mm)/2;xx1=[xx1(floor(mm/2)+1:mm),xx1(1:floor(mm/2))]/mm*m*2^OS(2);% frequency axis 1 with fft shift
xx2=([0:nn-1])-(nn)/2;xx2=[xx2(floor(nn/2)+1:nn),xx2(1:floor(nn/2))]/nn*n*2^OS(1);% frequency axis 2 with fft shift
[Xiie{1},Xiie{2}]=meshgrid(xx2,xx1);
clear xx1 xx2;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% --- get original wavepacket (USFFT), zero pad, get WP filter on regular grid (FFT)
FW=fftshift(fft2(ifftshift(datcoef))).*winchi./sqrt(numel( datcoef ));
fz=zeros(mm,nn); fz(DZ1+1:DZ1+N,DZ2+1:DZ2+N)=(2*Uoppp(xi{1},xi{2},FW(:),N,N,eps)*N); %fz=AMPS.*fz;
WP_winzp1=((fft2(fftshift(fz)))/m/n); clear fz;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% --- tensor product and reconstruction
% determine bandwidth, read out PSWF expansion EVs and coeffs
s1=1/2*(xi{1}*sin(tt)*Norm(1)+xi{2}*cos(tt)*Norm(2)).^2./(xi{1}*Norm(1)*cos(tt)-xi{2}*Norm(2)*sin(tt));
normwindow=winchi(:)/max(abs(winchi(:))); normwindow(normwindow<eps)=0; normwindow(normwindow>=eps)=1;
bandw=max(abs(abs(s1*max(abs(S2(:)))).*normwindow)); clear normwindow;
% get corresponding EVs and coefficients for PSWFs
cid=find(pswf.CC>=bandw);
    % control bandwidth too large for look-up-table: take maximum, clip d2S
    if isempty(cid); warning('BANDWIDTH TOO LARGE!!'); cid=length(pswf.CC); limS2=1;
    else cid=cid(1); limS2=0; end
    cc=pswf.CC(cid);
    if limS2; % clip d2S
        m1=max(abs(s1(:))); m2=cc/m1;
        id=find(abs(S2)>m2); S2(id)=sign(S2(id))*m2;bandw=cc;
    end
lambda=pswf.LAMBDA{cid}; djk=pswf.DJK{cid};

% get frequencies in expansion coordinates
XiI= +Xiie{1}*Norm(1)/2^OS(1)*cos(tt)-Xiie{2}*Norm(2)/2^OS(2)*sin(tt);
XiII=+Xiie{1}*Norm(1)/2^OS(1)*sin(tt)+Xiie{2}*Norm(2)/2^OS(2)*cos(tt);
warning off; CVcoord=-1/2*XiII.^2./XiI; warning on;
Thrid=find((abs(CVcoord*max(abs(S2(:))))<=bandw));
CVcoord(abs(CVcoord*max(abs(S2(:))))>bandw)=0;
clear XiI XiII;

% calculate expansion functions: PSWFs
S2=fftshift(S2);
[Gam_xi,Gam_x,nE] = pswf1d_sep_mexpp(CVcoord(Thrid),S2,cc,djk,lambda,1);
clear cc djk lambda CVcoord;

% reconstruct in co-moving frame of reference
IMpswfreg=zeros(mm,nn); tmpE=zeros(size(WP_winzp1));
for eid=1:nE;
    tmpE(Thrid)=Gam_xi(:,eid); 
    tmp=((ifft2(WP_winzp1.*tmpE)));
    IMpswfreg=IMpswfreg + m*n*reshape(Gam_x(:,eid),size(S2)).*(tmp);
end
clear tmpE tmp Gam_xi Gam_x Thrid S2 WP_winzp1;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% --- apply coordinate transform
WP_winzp2=((fft2((IMpswfreg)))/m/n);
clear IMpswfreg;
usrec=us2usfftpp(Xiie{1}(:),Xiie{2}(:),WP_winzp2(:),2^OS(1)*N,2^OS(2)*N,xcte1(:),xcte2(:),1e-7,0)*(N^2)/(NZ1*NZ2); usrec=usrec.*(AMPS);
