function [usrec] = BoxZOppcomplex(datcoef,winchi,xi,xcte1,xcte2,AMPS,N,Nip,OS,eps)
%% function [usrec] = BoxZOppcomplex(datcoef,winchi,xi,xcte1,xcte2,AMPS,N,Nip,OS,eps)
% zero order propagation of single box
% ---input: 
% datcoef - wave packet coefficients of box
% winchi - window function of box
% xi - frequency grid of box
% xcte1, xcte2 - coordinate transform: spatial evaluation points of adjoint USFFT
% AMPS - amplitudes corresponding to (xcte1, xcte2)
% N,Nip,OS,eps - image size, interpolation points, oversampling, precision
% ---output: 
% usrec - propagated data


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% --- define space and frequencies
m=Nip; n=Nip;
mm=2^(ceil(log2(m))+OS(2)); nn=2^(ceil(log2(n))+OS(1));
NZ1=mm; DZ1=(NZ1-m)/2; NZ2=nn; DZ2=(NZ2-n)/2;

% regularly spaced frequencies for CT USFFT
xx1=([0:mm-1])-(mm)/2;xx1=[xx1(floor(mm/2)+1:mm),xx1(1:floor(mm/2))]/mm*m*2^OS(2);% frequency axis 1 with fft shift
xx2=([0:nn-1])-(nn)/2;xx2=[xx2(floor(nn/2)+1:nn),xx2(1:floor(nn/2))]/nn*n*2^OS(1);% frequency axis 2 with fft shift
[xict{1},xict{2}]=meshgrid(xx2,xx1); clear xx1 xx2;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% --- get original wavepacket (USFFT), zero pad, get WP filter on regular grid (FFT)
FW=fftshift(fft2(ifftshift(datcoef))).*winchi./sqrt(numel( datcoef ));
fz=zeros(mm,nn); fz(DZ1+1:DZ1+N,DZ2+1:DZ2+N)=(2*Uoppp(xi{1},xi{2},FW(:),N,N,eps)*N);
WP_winzp1=((fft2(fftshift(fz)))/m/n); clear fz;
usrec=us2usfftpp(xict{1}(:),xict{2}(:),WP_winzp1,2^OS(1)*N,2^OS(2)*N,xcte1(:),xcte2(:),1e-7,0)*(N^2)/(NZ1*NZ2).*(AMPS);
%
